import javax.swing.JOptionPane;
import javax.swing.Timer;
import javax.swing.JFrame;
import java.util.Observer;
import java.util.Observable;


/**
 * In this version, we take advantage of the Observer/Observable framework to
 * give one of the Counters TWO Observers: one that prints its value to System.out,
 * and one that displays its value in the graphics window.  Note that the
 * Counter class doesn't change at all; it doesn't need to know how it's
 * being displayed, or even how MANY ways it's being displayed.
 * We could add yet another Observer that emails the current value of the
 * Counter to Dr. Bloch, and Counter still wouldn't need to be changed.
 * @since version 3, Feb 2
 * @version 8, Feb 2
 */
public class Testbed
{
    public static void test ()
    {
        final Counter a = new Counter ();
        // note a must be final, because it's a local var used inside an inner class
        final Counter b = new Counter ();
        a.addObserver (new Observer () {
            public void update (Observable o, Object newValue) {
                System.out.println ("Counter a value: " + newValue);
            }
        });
        b.addObserver (new Observer () {
            public void update (Observable o, Object newValue) {
                System.out.println ("Counter b value: " + newValue);
            }
        });
        
        javax.swing.SwingUtilities.invokeLater (new Runnable () {
            public void run () {
                JFrame theFrame = new JFrame ("Counter a");
                theFrame.setSize (100, 100);
                CounterComponent aWindow = new CounterComponent ();
                theFrame.add (aWindow);
                theFrame.setVisible (true);
                a.addObserver (aWindow);
            }
        });

        Timer timerA = new Timer(1000, a.getIncrementer());
        Timer timerB = new Timer(2000, b.getIncrementer());
        timerB.start();
        timerA.start();
        JOptionPane.showMessageDialog(null, "Quit?");
        System.exit(0);
    }
}
