import javax.swing.*;
import java.awt.*;
import java.util.Observer;
import java.util.Observable;
/**
 * A graphical view of a Counter.
 * In this version, the constructor creates a JFrame in which to display
 * the counter, and attaches the Component as an observer of the counter.
 * 
 * @author Stephen Bloch
 * @version 9, Feb 2
 */

public class CounterComponent extends JComponent implements Observer
{
    private String display = "";
    
    /**
     * Construct a CounterComponent to display a specified Counter.
     * @param toWatch  the Counter whose value this component should show
     * @param frameName the name of the window
     */
    public CounterComponent (Counter toWatch, final String frameName)
    {
        javax.swing.SwingUtilities.invokeLater (new Runnable () {
            public void run () {
                JFrame frame = new JFrame (frameName);
                frame.setSize (200, 100);
                frame.add (CounterComponent.this);
                frame.setVisible (true);
            }
        });
        toWatch.addObserver (this);
    }
    
    public void paintComponent (Graphics g)
    {
        g.drawString (this.display, 100, 40);
    }
    
    public void update (Observable o, Object newValue)
    {
        this.display = newValue.toString(); // should be an Integer
        this.repaint ();
    }
}
